* Virtual.PRG                                                               *
* Copyright (c) Genus Microprogramming, Inc. 1988-89  All Rights Reserved.  *

*****************************************************************************
*                                                                           *
* This program demonstrates the usage of a virtual window. It is an example *
* Pascal routine for the PCX Programmer's Toolkit.                          *
*                                                                           *
* Nantucket Clipper                       Programmer: Chris Howard  4/15/89 *
*                                                                           *
*****************************************************************************


* Include the PCX Toolkit defines
SET PROCEDURE TO pcxlib
DO  pcxInit

PRIVATE  pcximage,pcxtype

* Globals
pcxtype  = pcxVGA_11
pcximage = "Virtual.PCX"

bufmax   = 20000
buffer   = SPACE(bufmax)

vi       = SPACE(4)
header   = SPACE(128)

vptr     = SPACE(4)

**********

* Main

  * Display program header
  ?
  ? "͸"
  ? " Virtual: Example Virtual Clipper Program   PCX Programmer's Toolkit 3.50 "
  ? " Copyright (c) Genus Microprogramming, Inc. 1988-89  All Rights Reserved. "
  ? ";"
  ?

  * Allocate a larger toolkit buffer, to speed up file and display speed.
  retcode = pcxSB(buffer,bufmax);

  * Check if we have expanded memory, and display
  IF (PCXEMI() = pcxSUCCESS)
    vfree = pcxVE(pcxEMM)
    ? "Free EMM: ",vfree
  ENDIF

  * Display the amount of conventional memory free
  vfree = pcxVE(pcxCMM)
  ? "Free CMM: ",vfree

  * Look at the current hardware, to find a B/W mode
  pcxVI(vi)

  adapter = ASC(SUBSTR(vi,1,1))

  DO CASE
    CASE adapter = viCGA
      pcxtype = pcxCGA_6
    CASE adapter = viEGA
      IF (ASC(SUBSTR(vi,2,1)) = viMDAdisp)
        pcxtype = pcxEGA_F
      ELSE
        pcxtype = pcxEGA_10
      ENDIF
    CASE adapter = viVGA
      pcxtype = pcxVGA_11
    CASE adapter = viHGC
      pcxtype = pcxHERC
    OTHERWISE
      pcxtype = -1
  ENDCASE

  * If we found a mode, continue
  IF (pcxtype <> -1)

    * Get the file header
    retcode = pcxGFH(pcximage,header)
    IF (retcode = pcxSUCCESS)

      * Calculate the width and depth
      x1 = ASC(SUBSTR(header, 5,1))+ASC(SUBSTR(header, 6,1))*256
      y1 = ASC(SUBSTR(header, 7,1))+ASC(SUBSTR(header, 8,1))*256
      x2 = ASC(SUBSTR(header, 9,1))+ASC(SUBSTR(header,10,1))*256
      y2 = ASC(SUBSTR(header,11,1))+ASC(SUBSTR(header,12,1))*256

      width = (x2-x1)+1
      depth = (y2-y1)+1

      * Calculate the memory required
      vreq = pcxVZ(pcxtype,width,depth)
      ? "Reqd CMM: ",vreq
    
      * Get a key, to begin
      ? "Press a key to run . . ."
      INKEY(0)

      * Do we have enough?
      IF (vreq < vfree)
    
        * Yes, so create the virtual buffer
        retcode = pcxCV(pcxEMM,vptr,pcxtype,width,depth)
        IF (retcode = pcxSUCCESS)

          * Load the image into the virtual buffer
          retcode = pcxFV(pcximage,vptr)
          IF (retcode = pcxSUCCESS)
    
            * We loaded, so define a window 160x160 (remember, 0 to 159 = 160)
            wx2 = 159
            wy2 = 159
    
            * NOTE: NEVER DEFINE A WINDOW LARGER THAN THE IMAGE FOR SCROLLING!
            if (wx2 > width-1)
              wx2 = width-1
            ENDIF
            if (wy2 > depth-1)
              wy2 = depth-1
            ENDIF
    
            * Set the display type and mode
            pcxSD(pcxtype)
            pcxSM(pcxGRAPHICS)
    
            * Scroll the image
            retcode = pcxVS(vptr,width,depth,0,0,wx2,wy2,0)
    
            * Get back to text mode
            pcxSM(pcxTEXT)
    
            * Were we successful?
            IF (retcode <> pcxSUCCESS)
              ? "VirtualScroll Error: ",retcode
            ENDIF
    
          ELSE
            * Error loading file to virtual buffer
            ? "Error loading file: ",retcode
          ENDIF

          * If we do not need the buffer, destroy it
          retcode = pcxDV(vptr)
    
        ELSE
          * Error creating virtual buffer
          ? "Error creating virtual buffer: ",retcode
        ENDIF

      ELSE
        * Not enough free memory
        ? "Not enough free memory . . ."
      ENDIF

    ELSE
      * Could not get image header
      ? "Could not load image header: ",retcode
    ENDIF

  ELSE
    * We could not find a good mode
    ? "Could not find a good mode type . . ."
  ENDIF


RETURN && Main

